@@ -16,7 +16,7 @@ from .extensions import (  # noqa
 from .resources import register_blueprints
 
 
-__version__ = "0.14.0"
+__version__ = "0.15.0"
 
 API_VERSION = __version__
 OPENAPI_VERSION = "3.1.0"
@@ -30,7 +30,7 @@ def create_app(config_override=None):
     """
     app = flask.Flask(__name__)
     app.config.from_object("bemserver_api.settings.Config")
-    app.config.from_envvar("FLASK_SETTINGS_FILE", silent=True)
+    app.config.from_envvar("BEMSERVER_API_SETTINGS_FILE", silent=True)
     app.config.from_object(config_override)
 
     database.init_app(app)
@@ -43,7 +43,6 @@ def create_app(config_override=None):
     api.init_app(app)
     register_blueprints(api)
 
-    bsc = BEMServerCore()
-    bsc.init_auth()
+    BEMServerCore()
 
     return app
