@@ -5,7 +5,7 @@ import marshmallow_sqlalchemy as msa
 from bemserver_core.model import Campaign
 
 from bemserver_api import AutoSchema, Schema, SortField
-from bemserver_api.extensions.ma_fields import Timezone
+from bemserver_api.extensions import ma_fields
 
 
 class CampaignSchema(AutoSchema):
@@ -14,9 +14,9 @@ class CampaignSchema(AutoSchema):
 
     id = msa.auto_field(dump_only=True)
     name = msa.auto_field(validate=ma.validate.Length(1, 80))
-    start_time = ma.fields.AwareDateTime()
-    end_time = ma.fields.AwareDateTime()
-    timezone = Timezone(
+    start_time = ma_fields.AwareDateTime()
+    end_time = ma_fields.AwareDateTime()
+    timezone = ma_fields.Timezone(
         required=True,
         metadata={
             "default": "UTC",
