@@ -6,6 +6,7 @@ import marshmallow_sqlalchemy as msa
 from bemserver_core.model import EventBySite
 
 from bemserver_api import AutoSchema, Schema
+from ..sites.schemas import SiteSchema
 
 
 class EventBySiteSchema(AutoSchema):
@@ -13,6 +14,7 @@ class EventBySiteSchema(AutoSchema):
         model = EventBySite
 
     id = msa.auto_field(dump_only=True)
+    site = ma.fields.Nested(SiteSchema(exclude=("id",)), dump_only=True)
 
 
 class EventBySiteQueryArgsSchema(Schema):
