@@ -6,6 +6,7 @@ import marshmallow_sqlalchemy as msa
 from bemserver_core.model import EventByZone
 
 from bemserver_api import AutoSchema, Schema
+from ..zones.schemas import ZoneSchema
 
 
 class EventByZoneSchema(AutoSchema):
@@ -13,6 +14,7 @@ class EventByZoneSchema(AutoSchema):
         model = EventByZone
 
     id = msa.auto_field(dump_only=True)
+    zone = ma.fields.Nested(ZoneSchema(exclude=("id",)), dump_only=True)
 
 
 class EventByZoneQueryArgsSchema(Schema):
