@@ -4,7 +4,7 @@ from flask_smorest import abort
 
 from bemserver_core.model import TimeseriesByZone
 
-from bemserver_api import Blueprint
+from bemserver_api import Blueprint, SQLCursorPage
 from bemserver_api.database import db
 
 from .schemas import (
@@ -24,15 +24,14 @@ blp = Blueprint(
 @blp.route("/")
 class TimeseriesByZoneViews(MethodView):
     @blp.login_required
-    @blp.etag
     @blp.arguments(TimeseriesByZoneQueryArgsSchema, location="query")
     @blp.response(200, TimeseriesByZoneSchema(many=True))
+    @blp.paginate(SQLCursorPage)
     def get(self, args):
         """List timeseries x zone associations"""
         return TimeseriesByZone.get(**args)
 
     @blp.login_required
-    @blp.etag
     @blp.arguments(TimeseriesByZoneSchema)
     @blp.response(201, TimeseriesByZoneSchema)
     @blp.catch_integrity_error
@@ -46,7 +45,6 @@ class TimeseriesByZoneViews(MethodView):
 @blp.route("/<int:item_id>")
 class TimeseriesByZoneByIdViews(MethodView):
     @blp.login_required
-    @blp.etag
     @blp.response(200, TimeseriesByZoneSchema)
     def get(self, item_id):
         """Get timeseries x zone association by ID"""
@@ -56,28 +54,11 @@ class TimeseriesByZoneByIdViews(MethodView):
         return item
 
     @blp.login_required
-    @blp.etag
-    @blp.arguments(TimeseriesByZoneSchema)
-    @blp.response(200, TimeseriesByZoneSchema)
-    @blp.catch_integrity_error
-    def put(self, new_item, item_id):
-        """Update an existing timeseries x zone association"""
-        item = TimeseriesByZone.get_by_id(item_id)
-        if item is None:
-            abort(404)
-        blp.check_etag(item, TimeseriesByZoneSchema)
-        item.update(**new_item)
-        db.session.commit()
-        return item
-
-    @blp.login_required
-    @blp.etag
     @blp.response(204)
     def delete(self, item_id):
         """Delete a timeseries x zone association"""
         item = TimeseriesByZone.get_by_id(item_id)
         if item is None:
             abort(404)
-        blp.check_etag(item, TimeseriesByZoneSchema)
         item.delete()
         db.session.commit()
