@@ -4,10 +4,6 @@
 class Config:
     """Default configuration"""
 
-    # SQLAlchemy parameters
-    SQLALCHEMY_DATABASE_URI = ""
-    SQLALCHEMY_TRACK_MODIFICATIONS = False
-
     # API parameters
     API_TITLE = "BEMServer API"
     OPENAPI_JSON_PATH = "api-spec.json"
