@@ -14,14 +14,14 @@ BUILDINGS_URL = "/buildings/"
 
 class TestEnergyConsumptionTimeseriesByBuildingApi:
     def test_energy_consumption_timeseries_by_buildings_api(
-        self, app, users, buildings, timeseries, energy_sources, energy_end_uses
+        self, app, users, buildings, timeseries, energies, energy_end_uses
     ):
         creds = users["Chuck"]["creds"]
         building_1_id = buildings[0]
         building_2_id = buildings[1]
         ts_1_id = timeseries[0]
         ts_2_id = timeseries[1]
-        energy_source_1_id = energy_sources[1]
+        energy_1_id = energies[1]
         energy_end_use_1_id = energy_end_uses[1]
 
         client = app.test_client()
@@ -33,25 +33,25 @@ class TestEnergyConsumptionTimeseriesByBuildingApi:
             assert ret.json == []
 
             # POST
-            ectbs_1 = {
+            ectbb_1 = {
                 "building_id": building_1_id,
                 "timeseries_id": ts_1_id,
-                "source_id": energy_source_1_id,
+                "energy_id": energy_1_id,
                 "end_use_id": energy_end_use_1_id,
-                "wh_conversion_factor": 1,
             }
             ret = client.post(
-                ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL, json=ectbs_1
+                ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL, json=ectbb_1
             )
             assert ret.status_code == 201
             ret_val = ret.json
-            ectbs_1_id = ret_val.pop("id")
-            ectbs_1_etag = ret.headers["ETag"]
-            assert ret_val == ectbs_1
+            ectbb_1_id = ret_val.pop("id")
+            ectbb_1_etag = ret.headers["ETag"]
+            assert "id" not in ret_val.pop("timeseries")
+            assert ret_val == ectbb_1
 
             # POST violating unique constraint
             ret = client.post(
-                ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL, json=ectbs_1
+                ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL, json=ectbb_1
             )
             assert ret.status_code == 409
 
@@ -64,57 +64,58 @@ class TestEnergyConsumptionTimeseriesByBuildingApi:
 
             # GET by id
             ret = client.get(
-                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbs_1_id}"
+                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbb_1_id}"
             )
             assert ret.status_code == 200
-            assert ret.headers["ETag"] == ectbs_1_etag
+            assert ret.headers["ETag"] == ectbb_1_etag
             ret_val = ret.json
             ret_val.pop("id")
-            assert ret_val == ectbs_1
+            assert "id" not in ret_val.pop("timeseries")
+            assert ret_val == ectbb_1
 
             # PUT
-            ectbs_1["timeseries_id"] = ts_2_id
+            ectbb_1["timeseries_id"] = ts_2_id
             ret = client.put(
-                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbs_1_id}",
-                json=ectbs_1,
-                headers={"If-Match": ectbs_1_etag},
+                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbb_1_id}",
+                json=ectbb_1,
+                headers={"If-Match": ectbb_1_etag},
             )
             assert ret.status_code == 200
             ret_val = ret.json
             ret_val.pop("id")
-            ectbs_1_etag = ret.headers["ETag"]
-            assert ret_val == ectbs_1
+            ectbb_1_etag = ret.headers["ETag"]
+            assert "id" not in ret_val.pop("timeseries")
+            assert ret_val == ectbb_1
 
             # PUT wrong ID -> 404
             ret = client.put(
                 f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{DUMMY_ID}",
-                json=ectbs_1,
-                headers={"If-Match": ectbs_1_etag},
+                json=ectbb_1,
+                headers={"If-Match": ectbb_1_etag},
             )
             assert ret.status_code == 404
 
             # POST sep 2
-            ectbs_2 = {
+            ectbb_2 = {
                 "building_id": building_2_id,
                 "timeseries_id": ts_2_id,
-                "source_id": energy_source_1_id,
+                "energy_id": energy_1_id,
                 "end_use_id": energy_end_use_1_id,
-                "wh_conversion_factor": 1,
             }
             ret = client.post(
-                ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL, json=ectbs_2
+                ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL, json=ectbb_2
             )
             ret_val = ret.json
-            ectbs_2_id = ret_val.pop("id")
-            ectbs_2_etag = ret.headers["ETag"]
+            ectbb_2_id = ret_val.pop("id")
+            ectbb_2_etag = ret.headers["ETag"]
 
             # PUT violating unique constraint
-            ectbs_1["building_id"] = ectbs_2["building_id"]
-            ectbs_1["timeseries_id"] = ectbs_2["timeseries_id"]
+            ectbb_1["building_id"] = ectbb_2["building_id"]
+            ectbb_1["timeseries_id"] = ectbb_2["timeseries_id"]
             ret = client.put(
-                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbs_1_id}",
-                json=ectbs_1,
-                headers={"If-Match": ectbs_1_etag},
+                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbb_1_id}",
+                json=ectbb_1,
+                headers={"If-Match": ectbb_1_etag},
             )
             assert ret.status_code == 409
 
@@ -132,12 +133,12 @@ class TestEnergyConsumptionTimeseriesByBuildingApi:
             assert ret.status_code == 200
             ret_val = ret.json
             assert len(ret_val) == 1
-            assert ret_val[0]["id"] == ectbs_1_id
+            assert ret_val[0]["id"] == ectbb_1_id
 
             # DELETE wrong ID -> 404
             ret = client.delete(
                 f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{DUMMY_ID}",
-                headers={"If-Match": ectbs_1_etag},
+                headers={"If-Match": ectbb_1_etag},
             )
             assert ret.status_code == 404
 
@@ -151,13 +152,13 @@ class TestEnergyConsumptionTimeseriesByBuildingApi:
 
             # DELETE
             ret = client.delete(
-                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbs_1_id}",
-                headers={"If-Match": ectbs_1_etag},
+                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbb_1_id}",
+                headers={"If-Match": ectbb_1_etag},
             )
             assert ret.status_code == 404
             ret = client.delete(
-                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbs_2_id}",
-                headers={"If-Match": ectbs_2_etag},
+                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbb_2_id}",
+                headers={"If-Match": ectbb_2_etag},
             )
             assert ret.status_code == 204
 
@@ -169,7 +170,7 @@ class TestEnergyConsumptionTimeseriesByBuildingApi:
 
             # GET by id -> 404
             ret = client.get(
-                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbs_1_id}"
+                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbb_1_id}"
             )
             assert ret.status_code == 404
 
@@ -183,7 +184,7 @@ class TestEnergyConsumptionTimeseriesByBuildingApi:
         users,
         buildings,
         timeseries,
-        energy_sources,
+        energies,
         energy_end_uses,
         energy_consumption_timeseries_by_buildings,
     ):
@@ -191,9 +192,9 @@ class TestEnergyConsumptionTimeseriesByBuildingApi:
         building_1_id = buildings[0]
         ts_1_id = timeseries[0]
         ts_3_id = timeseries[2]
-        energy_source_1_id = energy_sources[1]
+        energy_1_id = energies[1]
         energy_end_use_1_id = energy_end_uses[1]
-        ectbs_1_id = energy_consumption_timeseries_by_buildings[0]
+        ectbb_1_id = energy_consumption_timeseries_by_buildings[0]
 
         client = app.test_client()
 
@@ -203,42 +204,42 @@ class TestEnergyConsumptionTimeseriesByBuildingApi:
             assert ret.status_code == 200
             ret_val = ret.json
             assert len(ret_val) == 1
-            ectbs_1 = ret_val[0]
-            assert ectbs_1.pop("id") == ectbs_1_id
+            ectbb_1 = ret_val[0]
+            assert "id" not in ectbb_1.pop("timeseries")
+            assert ectbb_1.pop("id") == ectbb_1_id
 
             # POST
-            ectbs_3 = {
+            ectbb_3 = {
                 "building_id": building_1_id,
                 "timeseries_id": ts_1_id,
-                "source_id": energy_source_1_id,
+                "energy_id": energy_1_id,
                 "end_use_id": energy_end_use_1_id,
-                "wh_conversion_factor": 1,
             }
             ret = client.post(
-                ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL, json=ectbs_3
+                ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL, json=ectbb_3
             )
             assert ret.status_code == 403
 
             # GET by id
             ret = client.get(
-                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbs_1_id}"
+                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbb_1_id}"
             )
             assert ret.status_code == 200
-            ectbs_1_etag = ret.headers["ETag"]
+            ectbb_1_etag = ret.headers["ETag"]
 
             # PUT
-            ectbs_1["timeseries_id"] = ts_3_id
+            ectbb_1["timeseries_id"] = ts_3_id
             ret = client.put(
-                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbs_1_id}",
-                json=ectbs_1,
-                headers={"If-Match": ectbs_1_etag},
+                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbb_1_id}",
+                json=ectbb_1,
+                headers={"If-Match": ectbb_1_etag},
             )
             assert ret.status_code == 403
 
             # DELETE
             ret = client.delete(
-                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbs_1_id}",
-                headers={"If-Match": ectbs_1_etag},
+                f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbb_1_id}",
+                headers={"If-Match": ectbb_1_etag},
             )
             assert ret.status_code == 403
 
@@ -248,7 +249,7 @@ class TestEnergyConsumptionTimeseriesByBuildingApi:
         building_1_id = buildings[0]
         ts_1_id = timeseries[0]
         ts_2_id = timeseries[1]
-        ectbs_1_id = energy_consumption_timeseries_by_buildings[0]
+        ectbb_1_id = energy_consumption_timeseries_by_buildings[0]
 
         client = app.test_client()
 
@@ -257,27 +258,27 @@ class TestEnergyConsumptionTimeseriesByBuildingApi:
         assert ret.status_code == 401
 
         # POST
-        ectbs_3 = {
+        ectbb_3 = {
             "building_id": building_1_id,
             "timeseries_id": ts_2_id,
         }
-        ret = client.post(ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL, json=ectbs_3)
+        ret = client.post(ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL, json=ectbb_3)
         assert ret.status_code == 401
 
         # GET by id
         ret = client.get(
-            f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbs_1_id}"
+            f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbb_1_id}"
         )
         assert ret.status_code == 401
 
         # PUT
-        ectbs_1 = {
+        ectbb_1 = {
             "building_id": building_1_id,
             "timeseries_id": ts_1_id,
         }
         ret = client.put(
-            f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbs_1_id}",
-            json=ectbs_1,
+            f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbb_1_id}",
+            json=ectbb_1,
             headers={"If-Match": "Dummy-ETag"},
         )
         # ETag is wrong but we get rejected before ETag check anyway
@@ -285,7 +286,7 @@ class TestEnergyConsumptionTimeseriesByBuildingApi:
 
         # DELETE
         ret = client.delete(
-            f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbs_1_id}",
+            f"{ENERGY_CONSUMPTION_TIMESERIES_BY_BUILDINGS_URL}{ectbb_1_id}",
             headers={"If-Match": "Dummy-Etag"},
         )
         # ETag is wrong but we get rejected before ETag check anyway
